@@ -76,6 +76,15 @@ void CreatePath(const char *Path,const wchar *PathW,bool SkipLastName)
         WideToChar(DirPtrW,DirName);
       else
       {
+#ifndef DBCS_SUPPORTED
+        if (*s!=CPATHDIVIDER)
+          for (const char *n=s;*n!=0 && n-Path<NM;n++)
+            if (*n==CPATHDIVIDER)
+            {
+              s=n;
+              break;
+            }
+#endif
         strncpy(DirName,Path,s-Path);
         DirName[s-Path]=0;
       }
@@ -90,19 +99,21 @@ void CreatePath(const char *Path,const wchar *PathW,bool SkipLastName)
     if (!IgnoreAscii)
       s=charnext(s);
   }
-  if (!SkipLastName)
+  if (!SkipLastName && !IsPathDiv(*PointToLastChar(Path)))
     MakeDir(Path,PathW,DirAttr);
 }
 
 
 void SetDirTime(const char *Name,RarTime *ftm,RarTime *ftc,RarTime *fta)
 {
-  bool sm=ftm!=NULL && ftm->IsSet();
-  bool sc=ftc!=NULL && ftc->IsSet();
-  bool sa=ftc!=NULL && fta->IsSet();
 #ifdef _WIN_32
   if (!WinNT())
     return;
+
+  bool sm=ftm!=NULL && ftm->IsSet();
+  bool sc=ftc!=NULL && ftc->IsSet();
+  bool sa=fta!=NULL && fta->IsSet();
+
   unsigned int DirAttr=GetFileAttr(Name);
   bool ResetAttr=(DirAttr!=0xffffffff && (DirAttr & FA_RDONLY)!=0);
   if (ResetAttr)
@@ -159,7 +170,7 @@ Int64 GetFreeDisk(const char *Name)
 
   if (pGetDiskFreeSpaceEx==NULL)
   {
-	HMODULE hKernel=GetModuleHandle("kernel32.dll");
+    HMODULE hKernel=GetModuleHandle("kernel32.dll");
     if (hKernel!=NULL)
       pGetDiskFreeSpaceEx=(GETDISKFREESPACEEX)GetProcAddress(hKernel,"GetDiskFreeSpaceExA");
   }
@@ -466,7 +477,7 @@ uint CalcFileCRC(File *SrcFile,Int64 Size)
   SrcFile->Seek(0,SEEK_SET);
   while ((ReadSize=SrcFile->Read(&Data[0],int64to32(Size==INT64ERR ? Int64(BufSize):Min(Int64(BufSize),Size))))!=0)
   {
-    BlockCount++;
+    ++BlockCount;
     if ((BlockCount & 15)==0)
     {
       Wait();
