@@ -27,6 +27,7 @@
 #define   MCHelpCmdA         "\n  a             Add files to archive"
 #define   MCHelpCmdC         "\n  c             Add archive comment"
 #define   MCHelpCmdCF        "\n  cf            Add files comment"
+#define   MCHelpCmdCH        "\n  ch            Change archive parameters"
 #define   MCHelpCmdCW        "\n  cw            Write archive comment to file"
 #define   MCHelpCmdD         "\n  d             Delete files from archive"
 #define   MCHelpCmdE         "\n  e             Extract files to current directory"
@@ -63,7 +64,7 @@
 #define   MCHelpSwDF         "\n  df            Delete files after archiving"
 #define   MCHelpSwDH         "\n  dh            Open shared files"
 #define   MCHelpSwDS         "\n  ds            Disable name sort for solid archive"
-#define   MCHelpSwEa         "\n  e<attr>       Set file exclude attributes"
+#define   MCHelpSwEa         "\n  e[+]<attr>    Set file exclude and include attributes"
 #define   MCHelpSwED         "\n  ed            Do not add empty directories"
 #define   MCHelpSwEE         "\n  ee            Do not save and extract extended attributes"
 #define   MCHelpSwEN         "\n  en            Do not put 'end of archive' block"
@@ -72,8 +73,9 @@
 #define   MCHelpSwEP2        "\n  ep2           Expand paths to full"
 #define   MCHelpSwEP3        "\n  ep3           Expand paths to full including the drive letter"
 #define   MCHelpSwF          "\n  f             Freshen files"
+#define   MCHelpSwFCU        "\n  fcu[file]     Read archive comment from Unicode file"
 #define   MCHelpSwHP         "\n  hp[password]  Encrypt both file data and headers"
-#define   MCHelpSwIDP        "\n  idp           Disable percentage display"
+#define   MCHelpSwIDP        "\n  id[c,d,p,q]   Disable messages"
 #define   MCHelpSwIEML       "\n  ieml[addr]    Send archive by email"
 #define   MCHelpSwIERR       "\n  ierr          Send all messages to stderr"
 #define   MCHelpSwILOG       "\n  ilog[name]    Log errors to file (registered versions only)"
@@ -86,10 +88,15 @@
 #define   MCHelpSwMC         "\n  mc<par>       Set advanced compression parameters"
 #define   MCHelpSwMD         "\n  md<size>      Dictionary size in KB (64,128,256,512,1024,2048,4096 or A-G)"
 #define   MCHelpSwMS         "\n  ms[ext;ext]   Specify file types to store"
+#define   MCHelpSwMT         "\n  mt<threads>   Set the number of threads"
+#define   MCHelpSwN          "\n  n<file>       Include only specified file"
+#define   MCHelpSwNa         "\n  n@            Read file names to include from stdin"
+#define   MCHelpSwNal        "\n  n@<list>      Include files in specified list file"
 #define   MCHelpSwOp         "\n  o+            Overwrite existing files"
 #define   MCHelpSwOm         "\n  o-            Do not overwrite existing files"
 #define   MCHelpSwOC         "\n  oc            Set NTFS Compressed attribute"
 #define   MCHelpSwOL         "\n  ol            Save symbolic links as the link instead of the file"
+#define   MCHelpSwOR         "\n  or            Rename files automatically"
 #define   MCHelpSwOS         "\n  os            Save NTFS streams"
 #define   MCHelpSwOW         "\n  ow            Save or restore file owner and group"
 #define   MCHelpSwP          "\n  p[password]   Set password"
@@ -103,6 +110,8 @@
 #define   MCHelpSwSm         "\n  s-            Disable solid archiving"
 #define   MCHelpSwSFX        "\n  sfx[name]     Create SFX archive"
 #define   MCHelpSwSI         "\n  si[name]      Read data from standard input (stdin)"
+#define   MCHelpSwSL         "\n  sl<size>      Process files with size less than specified"
+#define   MCHelpSwSM         "\n  sm<size>      Process files with size more than specified"
 #define   MCHelpSwT          "\n  t             Test files after archiving"
 #define   MCHelpSwTK         "\n  tk            Keep original archive time"
 #define   MCHelpSwTL         "\n  tl            Set archive time to latest file"
@@ -335,3 +344,4 @@
 #define   MMaxPathLimit      "\nTotal path and file name length must not exceed %d characters"
 #define   MRecVolLimit       "\nTotal number of usual and recovery volumes must not exceed 255"
 #define   MVolumeNumber      "volume %d"
+#define   MCannotDelete      "\nCannot delete %s"
